/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.document.library.internal.service;

import com.liferay.document.library.file.rank.service.DLFileRankLocalService;
import com.liferay.document.library.kernel.model.DLFileRank;
import com.liferay.document.library.kernel.service.DLAppLocalService;
import com.liferay.document.library.kernel.service.DLAppLocalServiceWrapper;
import com.liferay.petra.model.adapter.util.ModelAdapterUtil;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.service.ServiceWrapper;

import java.util.List;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Sergio González
 */
@Component(immediate = true, service = ServiceWrapper.class)
public class DLFileRankDLAppLocalServiceWrapper
	extends DLAppLocalServiceWrapper {

	public DLFileRankDLAppLocalServiceWrapper() {
		super(null);
	}

	public DLFileRankDLAppLocalServiceWrapper(
		DLAppLocalService dlAppLocalService) {

		super(dlAppLocalService);
	}

	@Override
	public DLFileRank addFileRank(
		long repositoryId, long companyId, long userId, long fileEntryId,
		ServiceContext serviceContext) {

		return ModelAdapterUtil.adapt(
			DLFileRank.class,
			_dlFileRankLocalService.addFileRank(
				repositoryId, companyId, userId, fileEntryId, serviceContext));
	}

	@Override
	public void deleteFileRanksByFileEntryId(long fileEntryId) {
		_dlFileRankLocalService.deleteFileRanksByFileEntryId(fileEntryId);
	}

	@Override
	public void deleteFileRanksByUserId(long userId) {
		_dlFileRankLocalService.deleteFileRanksByUserId(userId);
	}

	@Override
	public List<DLFileRank> getFileRanks(long repositoryId, long userId) {
		return ModelAdapterUtil.adapt(
			DLFileRank.class,
			_dlFileRankLocalService.getFileRanks(repositoryId, userId));
	}

	@Override
	public DLFileRank updateFileRank(
		long repositoryId, long companyId, long userId, long fileEntryId,
		ServiceContext serviceContext) {

		return ModelAdapterUtil.adapt(
			DLFileRank.class,
			_dlFileRankLocalService.updateFileRank(
				repositoryId, companyId, userId, fileEntryId, serviceContext));
	}

	@Reference
	private DLFileRankLocalService _dlFileRankLocalService;

}